/*
   File: placeholder.h
   Defines for which rules placeholders may be generated.
   No placeholders will be generated for rules that are external,
   predicate or semipredicate. No placeholder will be generated
   for the rule "layout".
  
   CVS ID: "$Id: placeholder.h,v 1.3 2004/12/26 00:48:46 marcs Exp $"
*/
#ifndef IncPlaceholder
#define IncPlaceholder

void decide_placeholders ();

#endif /* IncPlaceholder */
